# production

options(width=90)

precincts <- read.csv("general2004_rev_prod2.csv");

#> dim(precincts)
#[1] 11569   115
#> names(precincts)
#  [1] "countynum"              "county"                 "stateprecinctcode"
#  [4] "precinctname"           "split"                  "dist.congress"
#  [7] "dist.senateoh"          "dist.houseoh"           "dist.schoolboard"
# [10] "dist.courtofappeals"    "regvoters04"            "votescast04"
# [13] "kerry04"                "bush04"                 "indeppresa04"
# [16] "indeppresb04"           "dem.ussenate04"         "repub.ussenate04"
# [19] "chiefjusticea04"        "chiefjusticeb04"        "justice1a04"
# [22] "justice1b04"            "justice204"             "justice3a04"
# [25] "justice3b04"            "issueyes04"             "issueno04"
# [28] "dem.congress04"         "repub.congress04"       "indep.congress04"
# [31] "dem.senateoh04"         "repub.senateoh04"       "indep.senateoh04"
# [34] "dem.houseoh04"          "repub.houseoh04"        "indepa.houseoh04"
# [37] "indepb.houseoh04"       "boardofeda04"           "boardofedb04"
# [40] "boardofedc04"           "boardofedd04"           "courtofappeals1a04"
# [43] "courtofappeals1b04"     "courtofappeals2a04"     "courtofappeals2b04"
# [46] "courtofappeals3a04"     "courtofappeals3b04"     "courtofappeals4a04"
# [49] "courtofappeals4b04"     "courtofappeals4c04"     "courtofappeals5a04"
# [52] "courtofappeals5b04"     "courtofappeals6a04"     "courtofappeals6b04"
# [55] "constantboundaries0204" "absentee"               "federal"
# [58] "technology04"           "technology00"           "resid.pres04"
# [61] "resid.ussenate04"       "resid.scj04"            "mainsplit"
# [64] "precinctname02"         "regvoters02"            "votescast02"
# [67] "gov.dem02"              "gov.rep02"              "gov.ind02"
# [70] "precinctname03"         "regvoters03"            "votescast03"
# [73] "yes03"                  "no03"                   "FIPS"
# [76] "CNTY.VTD"               "CD108"                  "STHSE02"
# [79] "STSEN02"                "VAP"                    "VANHW"
# [82] "VANHAA"                 "VANHAP"                 "VANHNA"
# [85] "VANHOTHER"              "VAHISP"                 "PCT.VANHW"
# [88] "PCT.VANHAA"             "PCT.VANHAP"             "PCT.VANHNA"
# [91] "PCT.VANHO"              "PCT.VAHISP"             "MT.A.VAP"
# [94] "MT.B.VAP"               "MT.C.VAP"               "MT.D.VAP"
# [97] "MT.E.VAP"               "MT.F.VAP"               "MT.G.VAP"
#[100] "MT.H.VAP"               "MT.I.VAP"               "MT.J.VAP"
#[103] "MT.NA.VAP"              "MT.A.PCT"               "MT.B.PCT"
#[106] "MT.C.PCT"               "MT.D.PCT"               "MT.E.PCT"
#[109] "MT.F.PCT"               "MT.G.PCT"               "MT.H.PCT"
#[112] "MT.I.PCT"               "MT.J.PCT"               "MT.NA.PCT"
#[115] "machines04"

precincts$machtype <- factor(
  ifelse(precincts$technology04==1,"Punchcard",
  ifelse(precincts$technology04==2,"DRE",
  ifelse(precincts$technology04==3,"Opt Precinct",
  ifelse(precincts$technology04==4,"Opt Central", NA)))) );

precincts$machperreg <- precincts$machines04 / precincts$regvoters04 ;

logit <- function(x) {
  z <- ifelse(x<=0, .0000001, ifelse(x>=1, 1-.0000001, x));
  return( log(z/(1-z)) );
}

asc <- function(x) { as.character(x) }

precincts$county <- factor(toupper(asc(precincts$county)));

precincts$machtype <- factor(
  ifelse(asc(precincts$county)=="CUYAHOGA", "PCuyahoga",
  ifelse(asc(precincts$county)=="HAMILTON", "PHamilton",
  ifelse(precincts$technology04==1,"Punchcard",
  ifelse(precincts$technology04==2,"DRE",
  ifelse(precincts$technology04==3,"Opt Precinct",
  ifelse(precincts$technology04==4,"Opt Central", NA)))))) );

pconstantbds <- precincts[precincts$constantboundaries==1,c(2,11:18,26:27,65:69)];
pconstantbds$place <- precincts[precincts$constantboundaries==1,"precinctname"];
# > names(pconstantbds)
#  [1] "county"           "regvoters04"      "votescast04"      "kerry04"
#  [5] "bush04"           "indeppresa04"     "indeppresb04"     "dem.ussenate04"
#  [9] "repub.ussenate04" "issueyes04"       "issueno04"        "regvoters02"
# [13] "votescast02"      "gov.dem02"        "gov.rep02"        "gov.ind02"
# [17] "place"

pconstantbds$machtype <- precincts$machtype[precincts$constantboundaries==1];

pconstantbds$stateprecinctcode <-
  precincts[precincts$constantboundaries==1,"stateprecinctcode"];

keepidx <- pconstantbds$regvoters04 > 0 & pconstantbds$kerry04+pconstantbds$bush04 > 0;
pconstantbds <- pconstantbds[keepidx,];

keepidx <- !is.na(pconstantbds$votescast02);
pconstantbds <- pconstantbds[keepidx,];

pconstantbds$I1logit04 <- logit(pconstantbds$issueyes04/pconstantbds$votescast04);
pconstantbds$dsenlogit04 <- logit(pconstantbds$dem.ussenate04/pconstantbds$votescast04);
pconstantbds$dlogit02 <- logit(pconstantbds$gov.dem02/pconstantbds$votescast02);
pconstantbds$dlogit02b <- logit(pconstantbds$gov.dem02/
                                (pconstantbds$gov.dem02+pconstantbds$gov.rep02+
                                 pconstantbds$gov.ind02));

keepidx <- !is.na(pconstantbds$dlogit02) & is.finite(pconstantbds$dlogit02);
pconstantbds <- pconstantbds[keepidx,];

pcode <- pconstantbds$stateprecinctcode;

load(".Rdata.prec1O");

pconstantbds$stateprecinctcode <- pcode;

set.seed(19342);
if (!exists("multinomRob"))
	library(multinomRob, lib.loc="/home/wrm1/lib/R/");

showout <- function(cname) {
  zall[[cname]]$residuals.student[zall[[cname]]$weights[,2]==0]
}

model1 <- list(kerry04 ~ dsenlogit04,
              bush04 ~ -1
              );

model2 <- list(kerry04 ~ dlogit02,
              bush04 ~ -1
              );

model3 <- list(kerry04 ~ dlogit02b,
              bush04 ~ -1
              );

print(unique(asc(pconstantbds$county)));

print(summary(zall[["model1"]]));
if (!is.null(zall[["model1"]]$weights) && any(zall[["model1"]]$weights[,2]==0)) {
  print(pconstantbds[zall[["model1"]]$weights[,2]==0,c(1,16,15,2:3,10:11)]);
  print(showout("model1"));

  cat(paste(
    asc(pconstantbds[zall[["model1"]]$weights[,2]==0,c(1)]), " & ",
    asc(pconstantbds[zall[["model1"]]$weights[,2]==0,"stateprecinctcode"]), " & ",
    sapply(showout("model1"), function(n){sprintf(" %5.2f \\\\\n", n)})
  ));
}

print(summary(zall[["model2"]]));
if (!is.null(zall[["model2"]]$weights) && any(zall[["model2"]]$weights[,2]==0)) {
  print(pconstantbds[zall[["model2"]]$weights[,2]==0,c(1,16,15,2:3,10:11)]);
  print(showout("model2"));

  cat(paste(
    asc(pconstantbds[zall[["model2"]]$weights[,2]==0,c(1)]), " & ",
    asc(pconstantbds[zall[["model2"]]$weights[,2]==0,"stateprecinctcode"]), " & ",
    sapply(showout("model2"), function(n){sprintf(" %5.2f \\\\\n", n)})
  ));
}

print(summary(zall[["model3"]]));
if (!is.null(zall[["model3"]]$weights) && any(zall[["model3"]]$weights[,2]==0)) {
  print(pconstantbds[zall[["model3"]]$weights[,2]==0,c(1,16,15,2:3,10:11)]);
  print(showout("model3"));

  cat(paste(
    asc(pconstantbds[zall[["model3"]]$weights[,2]==0,c(1)]), " & ",
    asc(pconstantbds[zall[["model3"]]$weights[,2]==0,"stateprecinctcode"]), " & ",
    sapply(showout("model3"), function(n){sprintf(" %5.2f \\\\\n", n)})
  ));
}
