# production

options(width=90)

precincts <- read.csv("general2004_rev_prod2.csv");

# > dim(precincts)
# [1] 11569   114
# > names(precincts)
#   [1] "countynum"              "county"                 "stateprecinctcode"
#   [4] "precinctname"           "split"                  "dist.congress"
#   [7] "dist.senateoh"          "dist.houseoh"           "dist.schoolboard"
#  [10] "dist.courtofappeals"    "regvoters04"            "votescast04"
#  [13] "kerry04"                "bush04"                 "indeppresa04"
#  [16] "indeppresb04"           "dem.ussenate04"         "repub.ussenate04"
#  [19] "chiefjusticea04"        "chiefjusticeb04"        "justice1a04"
#  [22] "justice1b04"            "justice204"             "justice3a04"
#  [25] "justice3b04"            "issueyes04"             "issueno04"
#  [28] "dem.congress04"         "repub.congress04"       "indep.congress04"
#  [31] "dem.senateoh04"         "repub.senateoh04"       "indep.senateoh04"
#  [34] "dem.houseoh04"          "repub.houseoh04"        "indepa.houseoh04"
#  [37] "indepb.houseoh04"       "boardofeda04"           "boardofedb04"
#  [40] "boardofedc04"           "boardofedd04"           "courtofappeals1a04"
#  [43] "courtofappeals1b04"     "courtofappeals2a04"     "courtofappeals2b04"
#  [46] "courtofappeals3a04"     "courtofappeals3b04"     "courtofappeals4a04"
#  [49] "courtofappeals4b04"     "courtofappeals4c04"     "courtofappeals5a04"
#  [52] "courtofappeals5b04"     "courtofappeals6a04"     "courtofappeals6b04"
#  [55] "constantboundaries0204" "absentee"               "federal"
#  [58] "technology04"           "technology00"           "resid.pres04"
#  [61] "resid.ussenate04"       "resid.scj04"            "precinctname02"
#  [64] "regvoters02"            "votescast02"            "gov.dem02"
#  [67] "gov.rep02"              "gov.ind02"              "precinctname03"
#  [70] "regvoters03"            "votescast03"            "yes03"
#  [73] "no03"                   "FIPS"                   "CNTY.VTD"
#  [76] "CD108"                  "STHSE02"                "STSEN02"
#  [79] "VAP"                    "VANHW"                  "VANHAA"
#  [82] "VANHAP"                 "VANHNA"                 "VANHOTHER"
#  [85] "VAHISP"                 "PCT.VANHW"              "PCT.VANHAA"
#  [88] "PCT.VANHAP"             "PCT.VANHNA"             "PCT.VANHO"
#  [91] "PCT.VAHISP"             "MT.A.VAP"               "MT.B.VAP"
#  [94] "MT.C.VAP"               "MT.D.VAP"               "MT.E.VAP"
#  [97] "MT.F.VAP"               "MT.G.VAP"               "MT.H.VAP"
# [100] "MT.I.VAP"               "MT.J.VAP"               "MT.NA.VAP"
# [103] "MT.A.PCT"               "MT.B.PCT"               "MT.C.PCT"
# [106] "MT.D.PCT"               "MT.E.PCT"               "MT.F.PCT"
# [109] "MT.G.PCT"               "MT.H.PCT"               "MT.I.PCT"
# [112] "MT.J.PCT"               "MT.NA.PCT"              "machines04"

precincts$machtype <- factor(
  ifelse(precincts$technology04==1,"Punchcard",
  ifelse(precincts$technology04==2,"DRE",
  ifelse(precincts$technology04==3,"Opt Precinct",
  ifelse(precincts$technology04==4,"Opt Central", NA)))) );

precincts$machperreg <- precincts$machines04 / precincts$regvoters04 ;

logit <- function(x) {
  z <- ifelse(x<=0, .0000001, ifelse(x>=1, 1-.0000001, x));
  return( log(z/(1-z)) );
}

asc <- function(x) { as.character(x) }

precincts$county <- factor(toupper(asc(precincts$county)));

pconstantbds <- precincts[precincts$constantboundaries==1,c(2,11:18,26:27,64:68)];
pconstantbds$place <- precincts[precincts$constantboundaries==1,"precinctname"];
# > names(pconstantbds)
#  [1] "county"           "regvoters04"      "votescast04"      "kerry04"
#  [5] "bush04"           "indeppresa04"     "indeppresb04"     "dem.ussenate04"
#  [9] "repub.ussenate04" "issueyes04"       "issueno04"        "regvoters02"
# [13] "votescast02"      "gov.dem02"        "gov.rep02"        "gov.ind02"
# [17] "place"

pconstantbds$machtype <- precincts$machtype[precincts$constantboundaries==1];

pconstantbds$stateprecinctcode <-
  precincts[precincts$constantboundaries==1,"stateprecinctcode"];

#From: Michael Herron <Michael.C.Herron@Dartmouth.EDU>
#To: Walter Mebane <wrm1@macht.arts.cornell.edu>, Matt Rado <msr43@cornell.edu>,
#   Dan Wallach <dwallach@cs.rice.edu>, Eric Greenwald <eagreenwald@gmail.com>,
#   Juan Jover <juanjover@the-beach.net>
#Subject: guesses at counties with precinct movement
#Date: Fri, 3 Jun 2005 01:56:46 -0400
#
#Walter,
#
#Beyond Shelby, I'm willing to wager that the following places had some 
#precinct movement (or are associated with a lot of typos):
#
#Guernsey
#Licking
#Seneca
#
#I think this may be it.
#
#Michael
#
keepidx <- !(asc(pconstantbds$county) %in%
             c("GUERNSEY", "LICKING", "SENECA", "SHELBY"));
pconstantbds <- pconstantbds[keepidx,];

keepidx <- pconstantbds$regvoters04 > 0 & pconstantbds$kerry04+pconstantbds$bush04 > 0;
pconstantbds <- pconstantbds[keepidx,];

keepidx <- pconstantbds$regvoters04 > 0 & pconstantbds$kerry04+pconstantbds$bush04 > 0;
pconstantbds <- pconstantbds[keepidx,];

keepidx <- pconstantbds$regvoters04 >= pconstantbds$votescast04;
pconstantbds <- pconstantbds[keepidx,];

keepidx <- !is.na(pconstantbds$votescast02);
pconstantbds <- pconstantbds[keepidx,];

pconstantbds$nonvote04 <- pconstantbds$regvoters04 - pconstantbds$votescast04;
pconstantbds$nonvote02 <- pconstantbds$regvoters02 - pconstantbds$votescast02;
pconstantbds$vlogit02 <- logit(pconstantbds$votescast02/pconstantbds$regvoters02);

pconstantbds$I1logit04 <- logit(pconstantbds$issueyes04/pconstantbds$votescast04);
pconstantbds$dsenlogit04 <- logit(pconstantbds$dem.ussenate04/pconstantbds$votescast04);
pconstantbds$dlogit02 <- logit(pconstantbds$gov.dem02/pconstantbds$votescast02);
pconstantbds$dlogit02b <- logit(pconstantbds$gov.dem02/
                                (pconstantbds$gov.dem02+pconstantbds$gov.rep02+
                                 pconstantbds$gov.ind02));

pcode <- pconstantbds$stateprecinctcode;

load(".Rdata.precturnout2mN");

pconstantbds$stateprecinctcode <- pcode;

set.seed(19342);
if (!exists("multinomRob"))
	library(multinomRob, lib.loc="/home/wrm1/lib/R/");

showout <- function(cname) {
  zall[[cname]]$residuals.student[zall[[cname]]$weights[,2]==0]
}

model1 <- list(votescast04 ~ vlogit02 + I1logit04,
              nonvote04 ~ -1
              );

umachtype <- c("DRE","Opt Central","Opt Precinct","Punchcard");
for (i in umachtype) {
  tdat <- pconstantbds[asc(pconstantbds$machtype)==i,];
  print(i);

  print(summary(zall[[i]]));
  if (!is.null(zall[[i]]$weights) && any(zall[[i]]$weights[,2]==0)) {
    print(tdat[zall[[i]]$weights[,2]==0,c(1,17,16,2:5,10:11)]);
    print(showout(i));
  
    cat(paste(
      asc(tdat[zall[[i]]$weights[,2]==0,c(1)]), " & ",
      asc(tdat[zall[[i]]$weights[,2]==0,"stateprecinctcode"]), " & ",
      sapply(showout(i), function(n){sprintf(" %5.2f \\\\\n", n)})
    ));
  }
}
