# production

precincts <- read.csv("general2004_rev_prod2.csv");

#> dim(precincts)
#[1] 11569   115
#> names(precincts)
#  [1] "countynum"              "county"                 "stateprecinctcode"
#  [4] "precinctname"           "split"                  "dist.congress"
#  [7] "dist.senateoh"          "dist.houseoh"           "dist.schoolboard"
# [10] "dist.courtofappeals"    "regvoters04"            "votescast04"
# [13] "kerry04"                "bush04"                 "indeppresa04"
# [16] "indeppresb04"           "dem.ussenate04"         "repub.ussenate04"
# [19] "chiefjusticea04"        "chiefjusticeb04"        "justice1a04"
# [22] "justice1b04"            "justice204"             "justice3a04"
# [25] "justice3b04"            "issueyes04"             "issueno04"
# [28] "dem.congress04"         "repub.congress04"       "indep.congress04"
# [31] "dem.senateoh04"         "repub.senateoh04"       "indep.senateoh04"
# [34] "dem.houseoh04"          "repub.houseoh04"        "indepa.houseoh04"
# [37] "indepb.houseoh04"       "boardofeda04"           "boardofedb04"
# [40] "boardofedc04"           "boardofedd04"           "courtofappeals1a04"
# [43] "courtofappeals1b04"     "courtofappeals2a04"     "courtofappeals2b04"
# [46] "courtofappeals3a04"     "courtofappeals3b04"     "courtofappeals4a04"
# [49] "courtofappeals4b04"     "courtofappeals4c04"     "courtofappeals5a04"
# [52] "courtofappeals5b04"     "courtofappeals6a04"     "courtofappeals6b04"
# [55] "constantboundaries0204" "absentee"               "federal"
# [58] "technology04"           "technology00"           "resid.pres04"
# [61] "resid.ussenate04"       "resid.scj04"            "mainsplit"
# [64] "precinctname02"         "regvoters02"            "votescast02"
# [67] "gov.dem02"              "gov.rep02"              "gov.ind02"
# [70] "precinctname03"         "regvoters03"            "votescast03"
# [73] "yes03"                  "no03"                   "FIPS"
# [76] "CNTY.VTD"               "CD108"                  "STHSE02"
# [79] "STSEN02"                "VAP"                    "VANHW"
# [82] "VANHAA"                 "VANHAP"                 "VANHNA"
# [85] "VANHOTHER"              "VAHISP"                 "PCT.VANHW"
# [88] "PCT.VANHAA"             "PCT.VANHAP"             "PCT.VANHNA"
# [91] "PCT.VANHO"              "PCT.VAHISP"             "MT.A.VAP"
# [94] "MT.B.VAP"               "MT.C.VAP"               "MT.D.VAP"
# [97] "MT.E.VAP"               "MT.F.VAP"               "MT.G.VAP"
#[100] "MT.H.VAP"               "MT.I.VAP"               "MT.J.VAP"
#[103] "MT.NA.VAP"              "MT.A.PCT"               "MT.B.PCT"
#[106] "MT.C.PCT"               "MT.D.PCT"               "MT.E.PCT"
#[109] "MT.F.PCT"               "MT.G.PCT"               "MT.H.PCT"
#[112] "MT.I.PCT"               "MT.J.PCT"               "MT.NA.PCT"
#[115] "machines04"

precincts$machtype <- factor(
  ifelse(precincts$technology04==1,"Punchcard",
  ifelse(precincts$technology04==2,"DRE",
  ifelse(precincts$technology04==3,"Opt Precinct",
  ifelse(precincts$technology04==4,"Opt Central", NA)))) );

precincts$machperreg <- precincts$machines04 / precincts$regvoters04 ;

logit <- function(x) {
  z <- ifelse(x<=0, .0000001, ifelse(x>=1, 1-.0000001, x));
  return( log(z/(1-z)) );
}

asc <- function(x) { as.character(x) }

precincts$county <- factor(toupper(asc(precincts$county)));

precincts$machtype <- factor(
  ifelse(asc(precincts$county)=="CUYAHOGA", "PCuyahoga",
  ifelse(asc(precincts$county)=="HAMILTON", "PHamilton",
  ifelse(precincts$technology04==1,"Punchcard",
  ifelse(precincts$technology04==2,"DRE",
  ifelse(precincts$technology04==3,"Opt Precinct",
  ifelse(precincts$technology04==4,"Opt Central", NA)))))) );

pconstantbds <- precincts[precincts$constantboundaries==1,c(2,11:18,26:27,65:69,115)];
pconstantbds$machtype <- precincts[precincts$constantboundaries==1,"machtype"];
pconstantbds$machperreg <- precincts[precincts$constantboundaries==1,"machperreg"];
pconstantbds$place <- precincts[precincts$constantboundaries==1,"precinctname"];
# > names(pconstantbds)
#  [1] "county"           "regvoters04"      "votescast04"      "kerry04"
#  [5] "bush04"           "indeppresa04"     "indeppresb04"     "dem.ussenate04"
#  [9] "repub.ussenate04" "issueyes04"       "issueno04"        "regvoters02"
# [13] "votescast02"      "gov.dem02"        "gov.rep02"        "gov.ind02"
# [17] "machines04"       "machtype"         "machperreg"       "place"

keepidx <- pconstantbds$regvoters04 > 0 & pconstantbds$kerry04+pconstantbds$bush04 > 0;
pconstantbds <- pconstantbds[keepidx,];

pconstantbds$nonvote04 <- pconstantbds$regvoters04 - pconstantbds$votescast04;
pconstantbds$nonvote02 <- pconstantbds$regvoters02 - pconstantbds$votescast02;
pconstantbds$vlogit02 <- logit(pconstantbds$votescast02/pconstantbds$regvoters02);

pconstantbds$I1logit04 <- logit(pconstantbds$issueyes04/pconstantbds$votescast04);
pconstantbds$dsenlogit04 <- logit(pconstantbds$dem.ussenate04/pconstantbds$votescast04);
pconstantbds$dlogit02 <- logit(pconstantbds$gov.dem02/pconstantbds$votescast02);
pconstantbds$dlogit02b <- logit(pconstantbds$gov.dem02/
                                (pconstantbds$gov.dem02+pconstantbds$gov.rep02+
                                 pconstantbds$gov.ind02));

pconstantbds$lregvoters04 <- log(pconstantbds$regvoters04);
pconstantbds$toprop02 <- pconstantbds$votescast02/pconstantbds$regvoters02;
pconstantbds$ltoprop02 <- log(pconstantbds$votescast02/pconstantbds$regvoters02);
pconstantbds$lvotescast02 <- log(pconstantbds$votescast02);

keepidx <- !is.na(pconstantbds$ltoprop02) & is.finite(pconstantbds$ltoprop02);
pconstantbds <- pconstantbds[keepidx,];

summary(glm(machines04 ~ lregvoters04*machtype + lvotescast02*machtype,
            pconstantbds, family="quasipoisson"));

umachtype <- unique(asc(pconstantbds$machtype));
for (i in umachtype) {
  tdat <- pconstantbds[asc(pconstantbds$machtype)==i,];
  print(i);
  print(unique(asc(tdat$county)));
  print(summary(glm(machines04 ~ lregvoters04 + lvotescast02,
            tdat, family="poisson")));
}
