# production

precincts <- read.csv("general2004_rev_prod2.csv");

#> dim(precincts)
#[1] 11569   115
#> names(precincts)
#  [1] "countynum"              "county"                 "stateprecinctcode"
#  [4] "precinctname"           "split"                  "dist.congress"
#  [7] "dist.senateoh"          "dist.houseoh"           "dist.schoolboard"
# [10] "dist.courtofappeals"    "regvoters04"            "votescast04"
# [13] "kerry04"                "bush04"                 "indeppresa04"
# [16] "indeppresb04"           "dem.ussenate04"         "repub.ussenate04"
# [19] "chiefjusticea04"        "chiefjusticeb04"        "justice1a04"
# [22] "justice1b04"            "justice204"             "justice3a04"
# [25] "justice3b04"            "issueyes04"             "issueno04"
# [28] "dem.congress04"         "repub.congress04"       "indep.congress04"
# [31] "dem.senateoh04"         "repub.senateoh04"       "indep.senateoh04"
# [34] "dem.houseoh04"          "repub.houseoh04"        "indepa.houseoh04"
# [37] "indepb.houseoh04"       "boardofeda04"           "boardofedb04"
# [40] "boardofedc04"           "boardofedd04"           "courtofappeals1a04"
# [43] "courtofappeals1b04"     "courtofappeals2a04"     "courtofappeals2b04"
# [46] "courtofappeals3a04"     "courtofappeals3b04"     "courtofappeals4a04"
# [49] "courtofappeals4b04"     "courtofappeals4c04"     "courtofappeals5a04"
# [52] "courtofappeals5b04"     "courtofappeals6a04"     "courtofappeals6b04"
# [55] "constantboundaries0204" "absentee"               "federal"
# [58] "technology04"           "technology00"           "resid.pres04"
# [61] "resid.ussenate04"       "resid.scj04"            "mainsplit"
# [64] "precinctname02"         "regvoters02"            "votescast02"
# [67] "gov.dem02"              "gov.rep02"              "gov.ind02"
# [70] "precinctname03"         "regvoters03"            "votescast03"
# [73] "yes03"                  "no03"                   "FIPS"
# [76] "CNTY.VTD"               "CD108"                  "STHSE02"
# [79] "STSEN02"                "VAP"                    "VANHW"
# [82] "VANHAA"                 "VANHAP"                 "VANHNA"
# [85] "VANHOTHER"              "VAHISP"                 "PCT.VANHW"
# [88] "PCT.VANHAA"             "PCT.VANHAP"             "PCT.VANHNA"
# [91] "PCT.VANHO"              "PCT.VAHISP"             "MT.A.VAP"
# [94] "MT.B.VAP"               "MT.C.VAP"               "MT.D.VAP"
# [97] "MT.E.VAP"               "MT.F.VAP"               "MT.G.VAP"
#[100] "MT.H.VAP"               "MT.I.VAP"               "MT.J.VAP"
#[103] "MT.NA.VAP"              "MT.A.PCT"               "MT.B.PCT"
#[106] "MT.C.PCT"               "MT.D.PCT"               "MT.E.PCT"
#[109] "MT.F.PCT"               "MT.G.PCT"               "MT.H.PCT"
#[112] "MT.I.PCT"               "MT.J.PCT"               "MT.NA.PCT"
#[115] "machines04"

precincts$machtype <- factor(
  ifelse(precincts$technology04==1,"Punchcard",
  ifelse(precincts$technology04==2,"DRE",
  ifelse(precincts$technology04==3,"Opt Precinct",
  ifelse(precincts$technology04==4,"Opt Central", NA)))) );

precincts$machperreg <- precincts$machines04 / precincts$regvoters04 ;

logit <- function(x) {
  z <- ifelse(x<=0, .0000001, ifelse(x>=1, 1-.0000001, x));
  return( log(z/(1-z)) );
}

asc <- function(x) { as.character(x) }

precincts$county <- factor(toupper(asc(precincts$county)));

precincts$machtype <- factor(
  ifelse(asc(precincts$county)=="CUYAHOGA", "PCuyahoga",
  ifelse(asc(precincts$county)=="HAMILTON", "PHamilton",
  ifelse(asc(precincts$county)=="FRANKLIN", "DFranklin",
  ifelse(precincts$technology04==1,"Punchcard",
  ifelse(precincts$technology04==2,"DRE",
  ifelse(precincts$technology04==3,"Opt Precinct",
  ifelse(precincts$technology04==4,"Opt Central", NA))))))) );

precincts$VANHAAprop <- precincts$PCT.VANHAA / 100;
precincts$VANHAAlogit <- logit(precincts$VANHAAprop);

keepidx <- precincts$regvoters04 > 0 & precincts$kerry04+precincts$bush04 > 0;
precincts <- precincts[keepidx,];

precincts$nonvote04 <- precincts$regvoters04 - precincts$votescast04;
precincts$nonvote02 <- precincts$regvoters02 - precincts$votescast02;
precincts$vlogit02 <- logit(precincts$votescast02/precincts$regvoters02);

precincts$I1logit04 <- logit(precincts$issueyes04/precincts$votescast04);
precincts$dsenlogit04 <- logit(precincts$dem.ussenate04/precincts$votescast04);
precincts$dlogit02 <- logit(precincts$gov.dem02/precincts$votescast02);
precincts$dlogit02b <- logit(precincts$gov.dem02/
                                (precincts$gov.dem02+precincts$gov.rep02+
                                 precincts$gov.ind02));

precincts$lregvoters04 <- log(precincts$regvoters04);
precincts$toprop02 <- precincts$votescast02/precincts$regvoters02;
precincts$ltoprop02 <- log(precincts$votescast02/precincts$regvoters02);
precincts$lvotescast02 <- log(precincts$votescast02);

umachtype <- unique(asc(precincts$machtype));
for (i in umachtype) {
  tdat <- precincts[asc(precincts$machtype)==i,];
  print(i);
  print(unique(asc(tdat$county)));
  print(zq <- quantile(tdat$VANHAAprop, na.rm=TRUE))
  ttd <- tdat[zq[2] >= tdat$VANHAAprop,];
  mperr <- ttd$machines04/ttd$regvoters04
  print(median(mperr[!is.na(mperr)]))
  ttd <- tdat[(zq[2] < tdat$VANHAAprop) & (zq[4] >= tdat$VANHAAprop),];
  mperr <- ttd$machines04/ttd$regvoters04
  print(median(mperr[!is.na(mperr)]))
  ttd <- tdat[zq[4] < tdat$VANHAAprop,];
  mperr <- ttd$machines04/ttd$regvoters04
  print(median(mperr[!is.na(mperr)]))
}

