# production

options(width=90)

load(".Rdata.precturnout2mO");

set.seed(19342);
if (!exists("multinomRob"))
	library(multinomRob, lib.loc="/home/wrm1/lib/R/");

logit <- function(x) {
  z <- ifelse(x<=0, .0000001, ifelse(x>=1, 1-.0000001, x));
  return( log(z/(1-z)) );
}

asc <- function(x) { as.character(x) }

pconstantbds$machtypeA <- factor(
  ifelse(asc(pconstantbds$machtype)=="PCuyahoga","PC",
  ifelse(asc(pconstantbds$machtype)=="PHamilton","PH",
  ifelse(asc(pconstantbds$machtype)=="Punchcard","P",
  ifelse(asc(pconstantbds$machtype)=="DRE","DRE",
  ifelse(asc(pconstantbds$machtype)=="Opt Precinct","OP",
  ifelse(asc(pconstantbds$machtype)=="Opt Central","OC", NA)))))) );

model1 <- list(votescast04 ~ vlogit02 + I1logit04,
              nonvote04 ~ -1
              );

umachtype <- c("DRE","Opt Central","Opt Precinct","Punchcard","PCuyahoga","PHamilton");

simturnout <- function(x,m) {  # robust estimates
  bD  <- zall[[umachtype[1]]]$coefficients[,1]
  bOC <- zall[[umachtype[2]]]$coefficients[,1]
  bOP <- zall[[umachtype[3]]]$coefficients[,1]
  bP  <- zall[[umachtype[4]]]$coefficients[,1]
  bPC <- zall[[umachtype[5]]]$coefficients[,1]
  bPH <- zall[[umachtype[6]]]$coefficients[,1]

  l <- function(n) { 1/(1+exp(-n)) }

  tDRE <- l(bD[1] + bD[2] * m[1,1] + bD[3] * x[1,]);
  tOC  <- l(bOC[1] + bOC[2] * m[2,1] + bOC[3] * x[2,]);
  tOP  <- l(bOP[1] + bOP[2] * m[3,1] + bOP[3] * x[3,]);
  tP   <- l(bP[1] + bP[2] * m[4,1] + bP[3] * x[4,]);
  tPC  <- l(bPC[1] + bPC[2] * m[5,1] + bPC[3] * x[5,]);
  tPH  <- l(bPH[1] + bPH[2] * m[6,1] + bPH[3] * x[6,]);

  return(list(D=tDRE, OC=tOC, OP=tOP, P=tP, PC=tPC, PH=tPH));
}

mmat <- matrix(0, 6, 1);
dimnames(mmat) <- list(c("DRE","OC","OP","P", "PC", "PH"), NULL);
for (i in unique(asc(pconstantbds$machtypeA))) {
  tdat <- pconstantbds[asc(pconstantbds$machtypeA) == i,];
  mmat[i,] <- median(tdat$vlogit02)
}
print(mmat);

qmat <- matrix(0, 6, 3);
dimnames(qmat) <- list(c("DRE","OC","OP","P", "PC", "PH"), NULL);
for (i in unique(asc(pconstantbds$machtypeA))) {
  tdat <- pconstantbds[asc(pconstantbds$machtypeA) == i,];
  qmat[i,] <- quantile(tdat$I1logit04)[2:4]
}
print(qmat);

# robust
tsim <- simturnout(qmat,mmat);
print(tsim);
tfmt <- t(sapply(tsim,
          function(x){sapply(x,function(n){as.real(sprintf("%6.3f",n))})}));
print(tfmt);
