# production

precincts <- read.csv("general2004_rev_prod2.csv");

#> dim(precincts)
#[1] 11569   115
#> names(precincts)
#  [1] "countynum"              "county"                 "stateprecinctcode"
#  [4] "precinctname"           "split"                  "dist.congress"
#  [7] "dist.senateoh"          "dist.houseoh"           "dist.schoolboard"
# [10] "dist.courtofappeals"    "regvoters04"            "votescast04"
# [13] "kerry04"                "bush04"                 "indeppresa04"
# [16] "indeppresb04"           "dem.ussenate04"         "repub.ussenate04"
# [19] "chiefjusticea04"        "chiefjusticeb04"        "justice1a04"
# [22] "justice1b04"            "justice204"             "justice3a04"
# [25] "justice3b04"            "issueyes04"             "issueno04"
# [28] "dem.congress04"         "repub.congress04"       "indep.congress04"
# [31] "dem.senateoh04"         "repub.senateoh04"       "indep.senateoh04"
# [34] "dem.houseoh04"          "repub.houseoh04"        "indepa.houseoh04"
# [37] "indepb.houseoh04"       "boardofeda04"           "boardofedb04"
# [40] "boardofedc04"           "boardofedd04"           "courtofappeals1a04"
# [43] "courtofappeals1b04"     "courtofappeals2a04"     "courtofappeals2b04"
# [46] "courtofappeals3a04"     "courtofappeals3b04"     "courtofappeals4a04"
# [49] "courtofappeals4b04"     "courtofappeals4c04"     "courtofappeals5a04"
# [52] "courtofappeals5b04"     "courtofappeals6a04"     "courtofappeals6b04"
# [55] "constantboundaries0204" "absentee"               "federal"
# [58] "technology04"           "technology00"           "resid.pres04"
# [61] "resid.ussenate04"       "resid.scj04"            "mainsplit"
# [64] "precinctname02"         "regvoters02"            "votescast02"
# [67] "gov.dem02"              "gov.rep02"              "gov.ind02"
# [70] "precinctname03"         "regvoters03"            "votescast03"
# [73] "yes03"                  "no03"                   "FIPS"
# [76] "CNTY.VTD"               "CD108"                  "STHSE02"
# [79] "STSEN02"                "VAP"                    "VANHW"
# [82] "VANHAA"                 "VANHAP"                 "VANHNA"
# [85] "VANHOTHER"              "VAHISP"                 "PCT.VANHW"
# [88] "PCT.VANHAA"             "PCT.VANHAP"             "PCT.VANHNA"
# [91] "PCT.VANHO"              "PCT.VAHISP"             "MT.A.VAP"
# [94] "MT.B.VAP"               "MT.C.VAP"               "MT.D.VAP"
# [97] "MT.E.VAP"               "MT.F.VAP"               "MT.G.VAP"
#[100] "MT.H.VAP"               "MT.I.VAP"               "MT.J.VAP"
#[103] "MT.NA.VAP"              "MT.A.PCT"               "MT.B.PCT"
#[106] "MT.C.PCT"               "MT.D.PCT"               "MT.E.PCT"
#[109] "MT.F.PCT"               "MT.G.PCT"               "MT.H.PCT"
#[112] "MT.I.PCT"               "MT.J.PCT"               "MT.NA.PCT"
#[115] "machines04"

precincts$machtype <- factor(
  ifelse(precincts$technology04==1,"Punchcard",
  ifelse(precincts$technology04==2,"DRE",
  ifelse(precincts$technology04==3,"Opt Precinct",
  ifelse(precincts$technology04==4,"Opt Central", NA)))) );

precincts$machperreg <- precincts$machines04 / precincts$regvoters04 ;

logit <- function(x) {
  z <- ifelse(x<=0, .0000001, ifelse(x>=1, 1-.0000001, x));
  return( log(z/(1-z)) );
}

asc <- function(x) { as.character(x) }

precincts$county <- factor(toupper(asc(precincts$county)));

precincts$machtype <- factor(
  ifelse(asc(precincts$county)=="CUYAHOGA", "Punchcard\nCuyahoga",
  ifelse(asc(precincts$county)=="HAMILTON", "Punchcard\nHamilton",
  ifelse(precincts$technology04==1,"\nPunchcard",
  ifelse(precincts$technology04==2,"\nDRE",
  ifelse(precincts$technology04==3,"Optical\nPrecinct",
  ifelse(precincts$technology04==4,"Optical\nCentral", NA)))))) );

pconstantbds <- precincts[precincts$constantboundaries==1,c(2,11:18,26:27,65:69,115)];
pconstantbds$machtype <- precincts[precincts$constantboundaries==1,"machtype"];
pconstantbds$machperreg <- precincts[precincts$constantboundaries==1,"machperreg"];
pconstantbds$place <- precincts[precincts$constantboundaries==1,"precinctname"];
# > names(pconstantbds)
#  [1] "county"           "regvoters04"      "votescast04"      "kerry04"
#  [5] "bush04"           "indeppresa04"     "indeppresb04"     "dem.ussenate04"
#  [9] "repub.ussenate04" "issueyes04"       "issueno04"        "regvoters02"
# [13] "votescast02"      "gov.dem02"        "gov.rep02"        "gov.ind02"
# [17] "machines04"       "machtype"         "machperreg"       "place"

keepidx <- pconstantbds$regvoters04 > 0 & pconstantbds$kerry04+pconstantbds$bush04 > 0;
pconstantbds <- pconstantbds[keepidx,];

keepidx <- pconstantbds$regvoters04 >= pconstantbds$votescast04;
pconstantbds <- pconstantbds[keepidx,];

keepidx <- !is.na(pconstantbds$votescast02);
pconstantbds <- pconstantbds[keepidx,];

keepidx <- !is.na(pconstantbds$machperreg);
pconstantbds <- pconstantbds[keepidx,];

pconstantbds$nonvote04 <- pconstantbds$regvoters04 - pconstantbds$votescast04;
pconstantbds$nonvote02 <- pconstantbds$regvoters02 - pconstantbds$votescast02;
pconstantbds$vlogit02 <- logit(pconstantbds$votescast02/pconstantbds$regvoters02);

pconstantbds$I1prop04 <- pconstantbds$issueyes04/pconstantbds$votescast04;
pconstantbds$I1logit04 <- logit(pconstantbds$issueyes04/pconstantbds$votescast04);
pconstantbds$dsenlogit04 <- logit(pconstantbds$dem.ussenate04/pconstantbds$votescast04);
pconstantbds$dlogit02 <- logit(pconstantbds$gov.dem02/pconstantbds$votescast02);
pconstantbds$dlogit02b <- logit(pconstantbds$gov.dem02/
                                (pconstantbds$gov.dem02+pconstantbds$gov.rep02+
                                 pconstantbds$gov.ind02));

pconstantbds$toprop04 <- pconstantbds$votescast04/pconstantbds$regvoters04;
pconstantbds$toprop02 <- pconstantbds$votescast02/pconstantbds$regvoters02;
pconstantbds$tochg <- pconstantbds$toprop04-pconstantbds$toprop02;

pconstantbds$govprop <- pconstantbds$gov.dem02/
                        (pconstantbds$gov.dem02+pconstantbds$gov.rep02+
                         pconstantbds$gov.ind02);
pconstantbds$kerryprop <- pconstantbds$kerry04/
                          (pconstantbds$kerry04+pconstantbds$bush04);

keepidx <- !is.na(pconstantbds$dlogit02) & is.finite(pconstantbds$dlogit02) &
           !is.na(pconstantbds$vlogit02) & is.finite(pconstantbds$vlogit02);
pconstantbds <- pconstantbds[keepidx,];

unique(asc(pconstantbds$county));
unique(asc(pconstantbds$machtype));

postscript(file="precturnout4sA.ps", onefile=FALSE, horizontal=FALSE, width=6, height=6);
par(mfrow=c(1,1))
plot(pconstantbds$machtype, pconstantbds$toprop04, ylab="voter turnout rate", cex.axis=0.75);
dev.off()

postscript(file="precturnout4sB.ps", onefile=FALSE, horizontal=FALSE, width=6, height=6);
par(mfrow=c(1,1))
plot(c(0,1),c(0,1), type="n",
     ylab="voter turnout rate 2004", xlab="voter turnout rate 2002");
points(pconstantbds$toprop02, pconstantbds$toprop04);
abline(lm(pconstantbds$toprop04 ~ pconstantbds$toprop02));
dev.off()

postscript(file="precturnout4sBB.ps", onefile=FALSE, horizontal=FALSE, width=6, height=6);
#umachtype <- c("DRE","Opt Central","Opt Precinct","Punchcard");
umachtype <- c("\nDRE","Optical\nCentral","Optical\nPrecinct","\nPunchcard",
               "Punchcard\nCuyahoga","Punchcard\nHamilton");
par(mfrow=c(3,3))
for (i in umachtype) {
  tdat <- pconstantbds[asc(pconstantbds$machtype)==i,];
  print(i);

  plot(c(0,1), c(0,1), type="n", main=i,
       ylab="voter turnout rate 2004", xlab="voter turnout rate 2002");
  points(tdat$toprop02, tdat$toprop04);
  abline(lm(tdat$toprop04 ~ tdat$toprop02))
}
dev.off()

postscript(file="precturnout4sBC.ps", onefile=FALSE, horizontal=FALSE, width=6, height=6);
rngtochg <- range(pconstantbds$tochg);
rngtoprop <- range(pconstantbds$toprop04)
par(mfrow=c(3,3))
for (i in umachtype) {
  tdat <- pconstantbds[asc(pconstantbds$machtype)==i,];
  print(i);

  plot(rngtochg, rngtoprop, type="n", main=i,
       ylab="voter turnout rate 2004", xlab="turnout change 2002 to 2004");
  points(tdat$tochg, tdat$toprop04);
  abline(lm(tdat$toprop04 ~ tdat$tochg))
}
dev.off()

postscript(file="precturnout4sC.ps", onefile=FALSE, horizontal=FALSE, width=6, height=6);
par(mfrow=c(1,1))
tores <- lm(pconstantbds$toprop04 ~ pconstantbds$govprop)$res;
kerryres <- lm(pconstantbds$kerryprop ~ pconstantbds$govprop)$res;
kidx <- kerryres < 0.6;
tores <- tores[kidx];
kerryres <- kerryres[kidx];
rngtores <- range(tores);
rngkerryres <- range(kerryres);
plot(rngtores, rngkerryres, type="n",
     ylab="residualized Kerry vote proportion", xlab="residualized turnout 2004")
points(tores, kerryres);
abline(lm(kerryres ~ tores))
dev.off()

postscript(file="precturnout4sD.ps", onefile=FALSE, horizontal=FALSE, width=6, height=6);
#umachtype <- c("DRE","Opt Central","Opt Precinct","Punchcard");
umachtype <- c("\nDRE","Optical\nCentral","Optical\nPrecinct","\nPunchcard",
               "Punchcard\nCuyahoga","Punchcard\nHamilton");
par(mfrow=c(3,3))
tores <- lm(pconstantbds$toprop04 ~ pconstantbds$govprop)$res;
kerryres <- lm(pconstantbds$kerryprop ~ pconstantbds$govprop)$res;
kidx <- kerryres < 0.6;
rngtores <- range(tores[kidx]);
rngkerryres <- range(kerryres[kidx]);
for (i in umachtype) {
  tdat <- pconstantbds[asc(pconstantbds$machtype)==i,];
  tdat$tores <- tores[asc(pconstantbds$machtype)==i];
  tdat$kerryres <- kerryres[asc(pconstantbds$machtype)==i];
  print(i);
  kidx <- tdat$kerryres < 0.6;
  cat("omitting", sum(!kidx), "points\n");
  tdat <- tdat[kidx,];

  plot(rngtores, rngkerryres, type="n", main=i,
       ylab="residualized Kerry vote proportion", xlab="residualized turnout change 2004")
  points(tdat$tores, tdat$kerryres);
  abline(lm(tdat$kerryres ~ tdat$tores))
}
dev.off()

postscript(file="precturnout4sE.ps", onefile=FALSE, horizontal=FALSE, width=6, height=6);
par(mfrow=c(1,1))
tores <- lm(pconstantbds$toprop04 ~ pconstantbds$toprop02)$res;
I1res <- lm(pconstantbds$I1prop04 ~ pconstantbds$toprop02)$res;
kidx <- tores > -1.0;
tores <- tores[kidx];
I1res <- I1res[kidx];
rngtores <- range(tores);
rngI1res <- range(I1res);
plot(rngI1res, rngtores, type="n",
     xlab="residualized Issue 1 Yes vote", ylab="residualized turnout 2004")
points(I1res, tores);
abline(lm(tores ~ I1res))
dev.off()

postscript(file="precturnout4sF.ps", onefile=FALSE, horizontal=FALSE, width=6, height=6);
#umachtype <- c("DRE","Opt Central","Opt Precinct","Punchcard");
umachtype <- c("\nDRE","Optical\nCentral","Optical\nPrecinct","\nPunchcard",
               "Punchcard\nCuyahoga","Punchcard\nHamilton");
par(mfrow=c(3,3))
tores <- lm(pconstantbds$toprop04 ~ pconstantbds$toprop02)$res;
I1res <- lm(pconstantbds$I1prop04 ~ pconstantbds$toprop02)$res;
kidx <- tores > -1.0;
rngtores <- range(tores[kidx]);
rngI1res <- range(I1res[kidx]);
for (i in umachtype) {
  tdat <- pconstantbds[asc(pconstantbds$machtype)==i,];
  tdat$tores <- tores[asc(pconstantbds$machtype)==i];
  tdat$I1res <- I1res[asc(pconstantbds$machtype)==i];
  print(i);
  kidx <- tdat$tores > -1.0;
  cat("omitting", sum(!kidx), "points\n");
  tdat <- tdat[kidx,];

  plot(rngI1res, rngtores, type="n", main=i,
       xlab="residualized Issue 1 Yes vote", ylab="residualized turnout 2004")
  points(tdat$I1res, tdat$tores);
  abline(lm(tdat$tores ~ tdat$I1res))
}
dev.off()

postscript(file="precturnout4sG.ps", onefile=FALSE, horizontal=FALSE, width=6, height=6);
par(mfrow=c(1,1))
plot(c(0,1), c(0,1), type="n",
     ylab="Kerry vote proportion", xlab="Hagan vote proportion 2002");
points(pconstantbds$govprop, pconstantbds$kerryprop);
abline(lm(pconstantbds$kerryprop ~ pconstantbds$govprop));
dev.off()

postscript(file="precturnout4sH.ps", onefile=FALSE, horizontal=FALSE, width=6, height=6);
#umachtype <- c("DRE","Opt Central","Opt Precinct","Punchcard");
umachtype <- c("\nDRE","Optical\nCentral","Optical\nPrecinct","\nPunchcard",
               "Punchcard\nCuyahoga","Punchcard\nHamilton");
par(mfrow=c(3,3))
for (i in umachtype) {
  tdat <- pconstantbds[asc(pconstantbds$machtype)==i,];
  print(i);

  plot(c(0,1), c(0,1), type="n", main=i,
       ylab="Kerry vote proportion", xlab="Hagan vote proportion 2002")
  points(tdat$govprop, tdat$kerryprop);
  abline(lm(tdat$kerryprop ~ tdat$govprop))
}
dev.off()

postscript(file="precturnout4sI.ps", onefile=FALSE, horizontal=FALSE, width=6, height=6);
#umachtype <- c("DRE","Opt Central","Opt Precinct","Punchcard");
umachtype <- c("\nDRE","Optical\nCentral","Optical\nPrecinct","\nPunchcard",
               "Punchcard\nCuyahoga","Punchcard\nHamilton");
par(mfrow=c(3,3))
for (i in umachtype) {
  tdat <- pconstantbds[asc(pconstantbds$machtype)==i,];
  print(i);

  plot(tdat$regvoters02, tdat$regvoters04, main=i,
       ylab="registered voters 2004", xlab="registered voters 2002");
#  abline(lm(tdat$regvoters04 ~ tdat$regvoters02))
  abline(0,1)
}
dev.off()

postscript(file="precturnout4sJ.ps", onefile=FALSE, horizontal=FALSE, width=6, height=6);
#umachtype <- c("DRE","Opt Central","Opt Precinct","Punchcard");
umachtype <- c("\nDRE","Optical\nCentral","Optical\nPrecinct","\nPunchcard",
               "Punchcard\nCuyahoga","Punchcard\nHamilton");
rvchg <- (pconstantbds$regvoters04 - pconstantbds$regvoters02)/pconstantbds$regvoters02;
kidx <- rvchg<1.25 & pconstantbds$tochg > -1.0;
rngrvchg <- range(rvchg[kidx]);
rngtochg <- range(pconstantbds$tochg[kidx]);
par(mfrow=c(3,3))
for (i in umachtype) {
  tdat <- pconstantbds[asc(pconstantbds$machtype)==i,];
  trvchg <- (tdat$regvoters04 - tdat$regvoters02)/tdat$regvoters02;
  print(i);
  kidx <- trvchg<1.25 & tdat$tochg > -1.0;
  cat("omitting", sum(!kidx), "points\n");
  tdat <- tdat[kidx,];
  trvchg <- trvchg[kidx];

  plot(rngrvchg, rngtochg, type="n", main=i,
       ylab="turnout change 2002 to 2004", xlab="registration change 2002 to 2004");
  points(trvchg, tdat$tochg);
  abline(lm(tdat$tochg ~ trvchg))
}
dev.off()

postscript(file="precturnout4sK.ps", onefile=FALSE, horizontal=FALSE, width=6, height=6);
#umachtype <- c("DRE","Opt Central","Opt Precinct","Punchcard");
umachtype <- c("\nDRE","Optical\nCentral","Optical\nPrecinct","\nPunchcard",
               "Punchcard\nCuyahoga","Punchcard\nHamilton");
rvchg <- (pconstantbds$regvoters04 - pconstantbds$regvoters02)/pconstantbds$regvoters02;
kidx <- rvchg<1.25;
rngrvchg <- range(rvchg[kidx]);
par(mfrow=c(3,3))
for (i in umachtype) {
  tdat <- pconstantbds[asc(pconstantbds$machtype)==i,];
  trvchg <- (tdat$regvoters04 - tdat$regvoters02)/tdat$regvoters02;
  print(i);
  kidx <- trvchg<1.25;
  cat("omitting", sum(!kidx), "points\n");
  tdat <- tdat[kidx,];
  trvchg <- trvchg[kidx];

  plot(rngrvchg, c(0,1), type="n", main=i,
       ylab="Kerry vote proportion", xlab="registration change 2002 to 2004");
  points(trvchg, tdat$kerryprop);
  abline(lm(tdat$kerryprop ~ trvchg))
}
dev.off()

