# production

load(".Rdata.residmach6mN");

gen2004v$machtypeA <- factor(
  ifelse(gen2004v$technology04==1,"P",
  ifelse(gen2004v$technology04==2,"DRE",
  ifelse(gen2004v$technology04==3,"OP",
  ifelse(gen2004v$technology04==4,"OC", NA)))) );

asc <- function(x) { as.character(x) }

logit <- function(x) {
  eps <- .0001;
  z <- ifelse(x<=0, eps, ifelse(x>=1, 1-eps, x));
  return( log(z/(1-z)) );
}

model1 <- list(resid4 ~ machperreg + VANHAAprop,
              pres4 ~ -1
              );

umachtype <- c("dre", "optprecinct", "optcentral", "punchcard");

simturnout <- function(x,y) {  # robust estimates
  bD  <- zall[[umachtype[1]]]$coefficients[,1]
  bOP <- zall[[umachtype[2]]]$coefficients[,1]
  bOC <- zall[[umachtype[3]]]$coefficients[,1]
  bP  <- zall[[umachtype[4]]]$coefficients[,1]

  l <- function(n) { 1/(1+exp(-n)) }

  tDRE <- l(bD[1] + bD[2] * x[1,] + bD[3] * y[1]);
  tOC  <- l(bOC[1] + bOC[2] * x[2,] + bOC[3] * y[2]);
  tOP  <- l(bOP[1] + bOP[2] * x[3,] + bOP[3] * y[3]);
  tP   <- l(bP[1] + bP[2] * x[4,] + bP[3] * y[4]);

  return(list(D=tDRE, OC=tOC, OP=tOP, P=tP));
}

qmatAA <- matrix(0, 4, 3);
dimnames(qmatAA) <- list(c("DRE","OC","OP","P"), NULL);
for (i in unique(asc(gen2004v$machtypeA))) {
  tdat <- gen2004v[asc(gen2004v$machtypeA) == i,];
  qmatAA[i,] <- quantile(tdat$VANHAAprop)[2:4]
}
print(qmatAA);

qmat <- matrix(0, 4, 3);
dimnames(qmat) <- list(c("DRE","OC","OP","P"), NULL);
for (i in unique(asc(gen2004v$machtypeA))) {
  tdat <- gen2004v[asc(gen2004v$machtypeA) == i,];
  qmat[i,] <- quantile(tdat$machperreg)[2:4]
}
print(qmat);

# robust
tsim <- simturnout(qmat, qmatAA[,1]);
print(tsim);
tfmt <- t(sapply(tsim,
          function(x){sapply(x,function(n){as.real(sprintf("%6.4f",n))})}));
print(tfmt);

tsim <- simturnout(qmat, qmatAA[,2]);
print(tsim);
tfmt <- t(sapply(tsim,
          function(x){sapply(x,function(n){as.real(sprintf("%6.4f",n))})}));
print(tfmt);

tsim <- simturnout(qmat, qmatAA[,3]);
print(tsim);
tfmt <- t(sapply(tsim,
          function(x){sapply(x,function(n){as.real(sprintf("%6.4f",n))})}));
print(tfmt);
