# production

set.seed(19342);
if (!exists("multinomRob"))
	library(multinomRob, lib.loc="/home/wrm1/lib/R/");

wards <- read.csv("wards.csv");

# > dim(wards)
# [1] 353  64
# > names(wards)
#  [1] "county"             "city"               "ward"
#  [4] "regvoters04"        "votescast04"        "kerry04"
#  [7] "bush04"             "indeppresa04"       "indeppresb04"
# [10] "dem.ussenate04"     "repub.ussenate04"   "chiefjusticea04"
# [13] "chiefjusticeb04"    "justice1a04"        "justice1b04"
# [16] "justice204"         "justice3a04"        "justice3b04"
# [19] "issueyes04"         "issueno04"          "dem.congress04"
# [22] "repub.congress04"   "indep.congress04"   "dem.senateoh04"
# [25] "repub.senateoh04"   "indep.senateoh04"   "dem.houseoh04"
# [28] "repub.houseoh04"    "indepa.houseoh04"   "indepb.houseoh04"
# [31] "boardofeda04"       "boardofedb04"       "boardofedc04"
# [34] "boardofedd04"       "courtofappeals1a04" "courtofappeals1b04"
# [37] "courtofappeals2a04" "courtofappeals2b04" "courtofappeals3a04"
# [40] "courtofappeals3b04" "courtofappeals4a04" "courtofappeals4b04"
# [43] "courtofappeals4c04" "courtofappeals5a04" "courtofappeals5b04"
# [46] "courtofappeals6a04" "courtofappeals6b04" "machines04"
# [49] "VAP"                "VANHW"              "VANHAA"
# [52] "VANHAP"             "VANHNA"             "VANOTHER"
# [55] "VAHISP"             "regvoters03"        "votescast03"
# [58] "yes03"              "no03"               "regvoters02"
# [61] "votescast02"        "gov.dem02"          "gov.rep02"
# [64] "gov.ind02"

logit <- function(x) {
  z <- ifelse(x<=0, .0000001, ifelse(x>=1, 1-.0000001, x));
  return( log(z/(1-z)) );
}

asc <- function(x) { as.character(x) }

wards$I1logit04 <- logit(wards$issueyes04/wards$votescast04);
wards$dsenlogit04 <- logit(wards$dem.ussenate04/wards$votescast04);
wards$dlogit02 <- logit(wards$gov.dem02/(wards$gov.dem02+wards$gov.rep02));
wards$dlogit02b <- logit(wards$gov.dem02/
                        (wards$gov.dem02+wards$gov.rep02+wards$gov.ind02));

showout <- function(cname) {
  zall[[cname]]$residuals.student[zall[[cname]]$weights[,2]==0]
}

model1 <- list(kerry04 ~ dsenlogit04,
              bush04 ~ -1
              );

model2 <- list(kerry04 ~ dlogit02,
              bush04 ~ -1
              );

model3 <- list(kerry04 ~ dlogit02b,
              bush04 ~ -1
              );

## Set parameters for Genoud
zz.genoud.parms <- list( pop.size             = 1000,
                        wait.generations      = 10,
                        max.generations       = 100,
                        print.level = 0
                        )

options(error=quote(print("ulp!")));
zall <- list();

zall[["model1"]] <-
z2 <- try( multinomRob(model1,
               data=wards,
               genoud.parms   = zz.genoud.parms,
               maxiter = 10,
               print.level    = 1,
               iter = TRUE ) );

print(summary(z2));
if (!is.null(z2$weights) && any(z2$weights[,2]==0)) {
  print(wards[z2$weights[,2]==0,c(1:11)]);
  print(showout("model1"));
}

zall[["model2"]] <-
z2 <- try( multinomRob(model2,
               data=wards,
               genoud.parms   = zz.genoud.parms,
               maxiter = 10,
               print.level    = 1,
               iter = TRUE ) );

print(summary(z2));
if (!is.null(z2$weights) && any(z2$weights[,2]==0)) {
  print(wards[z2$weights[,2]==0,c(1:11)]);
  print(showout("model2"));
}

zall[["model3"]] <-
z2 <- try( multinomRob(model3,
               data=wards,
               genoud.parms   = zz.genoud.parms,
               maxiter = 10,
               print.level    = 1,
               iter = TRUE ) );

print(summary(z2));
if (!is.null(z2$weights) && any(z2$weights[,2]==0)) {
  print(wards[z2$weights[,2]==0,c(1:11)]);
  print(showout("model3"));
}

save(wards, zall, file=".Rdata.wards1N");
