# production

wards <- read.csv("wards.csv");

# > dim(wards)
# [1] 357  64
# > names(wards)
#  [1] "county"             "city"               "ward"
#  [4] "regvoters04"        "votescast04"        "kerry04"
#  [7] "bush04"             "indeppresa04"       "indeppresb04"
# [10] "dem.ussenate04"     "repub.ussenate04"   "chiefjusticea04"
# [13] "chiefjusticeb04"    "justice1a04"        "justice1b04"
# [16] "justice204"         "justice3a04"        "justice3b04"
# [19] "issueyes04"         "issueno04"          "dem.congress04"
# [22] "repub.congress04"   "indep.congress04"   "dem.senateoh04"
# [25] "repub.senateoh04"   "indep.senateoh04"   "dem.houseoh04"
# [28] "repub.houseoh04"    "indepa.houseoh04"   "indepb.houseoh04"
# [31] "boardofeda04"       "boardofedb04"       "boardofedc04"
# [34] "boardofedd04"       "courtofappeals1a04" "courtofappeals1b04"
# [37] "courtofappeals2a04" "courtofappeals2b04" "courtofappeals3a04"
# [40] "courtofappeals3b04" "courtofappeals4a04" "courtofappeals4b04"
# [43] "courtofappeals4c04" "courtofappeals5a04" "courtofappeals5b04"
# [46] "courtofappeals6a04" "courtofappeals6b04" "machines04"
# [49] "VAP"                "VANHW"              "VANHAA"
# [52] "VANHAP"             "VANHNA"             "VANOTHER"
# [55] "VAHISP"             "regvoters03"        "votescast03"
# [58] "yes03"              "no03"               "regvoters02"
# [61] "votescast02"        "gov.dem02"          "gov.rep02"
# [64] "gov.ind02"

tech <- read.csv("OH_technology.csv");

# > names(tech)
# [1] "county"     "fips"       "technology"

logit <- function(x) {
  z <- ifelse(x<=0, .0000001, ifelse(x>=1, 1-.0000001, x));
  return( log(z/(1-z)) );
}

asc <- function(x) { as.character(x) }

wards$county <- factor(toupper(asc(wards$county)));

tech$countyUC <- factor(toupper(asc(tech$county)));
tech$machtype <- factor(
  ifelse(tech$technology==1,"Punchcard",
  ifelse(tech$technology==2,"DRE",
  ifelse(tech$technology==3,"Opt Precinct",
  ifelse(tech$technology==4,"Opt Central", NA)))) );

wards$machtype <- tech$machtype[match(asc(wards$county), tech$countyUC)];

wards$I1logit04 <- logit(wards$issueyes04/wards$votescast04);
wards$dsenlogit04 <- logit(wards$dem.ussenate04/wards$votescast04);
wards$dlogit02 <- logit(wards$gov.dem02/(wards$gov.dem02+wards$gov.rep02));
wards$dlogit02b <- logit(wards$gov.dem02/
                        (wards$gov.dem02+wards$gov.rep02+wards$gov.ind02));

wards$I1prop04 <- wards$issueyes04/wards$votescast04;

wards$toprop04 <- wards$votescast04/wards$regvoters04;
wards$toprop02 <- wards$votescast02/wards$regvoters02;
wards$tochg <- wards$toprop04-wards$toprop02;

wards$govprop <- wards$gov.dem02/
                 (wards$gov.dem02+wards$gov.rep02+wards$gov.ind02);
wards$kerryprop <- wards$kerry04/(wards$kerry04+wards$bush04);

unique(asc(wards$county));
unique(asc(wards$machtype));

umachtype <- c("DRE","Opt Central","Opt Precinct","Punchcard");
ucounty <- c("CUYAHOGA", "FRANKLIN", "HAMILTON", "LUCAS");
uCounty <- c("Cuyahoga", "Franklin", "Hamilton", "Lucas");

wards$UCounty <- factor(uCounty[match(wards$county, ucounty)]);

postscript(file="wards2sA.ps", onefile=FALSE, horizontal=FALSE, width=6, height=6);
par(mfrow=c(1,1))
plot(wards$UCounty, wards$toprop04, ylab="voter turnout rate");
dev.off()

postscript(file="wards2sB.ps", onefile=FALSE, horizontal=FALSE, width=6, height=6);
par(mfrow=c(1,1))
plot(c(0,1),c(0,1), type="n",
     ylab="voter turnout rate 2004", xlab="voter turnout rate 2002");
points(wards$toprop02, wards$toprop04);
abline(lm(wards$toprop04 ~ wards$toprop02));
dev.off()

postscript(file="wards2sBB.ps", onefile=FALSE, horizontal=FALSE, width=6, height=6);
par(mfrow=c(2,2))
for (i in 1:4) {
  tdat <- wards[asc(wards$county)==ucounty[i],];
  print(uCounty[i]);

  plot(c(0,1), c(0,1), type="n", main=uCounty[i],
       ylab="voter turnout rate 2004", xlab="voter turnout rate 2002");
  points(tdat$toprop02, tdat$toprop04);
  abline(lm(tdat$toprop04 ~ tdat$toprop02))
}
dev.off()

postscript(file="wards2sBC.ps", onefile=FALSE, horizontal=FALSE, width=6, height=6);
rngtochg <- range(wards$tochg);
rngtoprop <- range(wards$toprop04)
par(mfrow=c(2,2))
for (i in 1:4) {
  tdat <- wards[asc(wards$county)==ucounty[i],];
  print(uCounty[i]);

  plot(rngtochg, rngtoprop, type="n", main=uCounty[i],
       ylab="voter turnout rate 2004", xlab="turnout change 2002 to 2004");
  points(tdat$tochg, tdat$toprop04);
  abline(lm(tdat$toprop04 ~ tdat$tochg))
}
dev.off()

postscript(file="wards2sC.ps", onefile=FALSE, horizontal=FALSE, width=6, height=6);
par(mfrow=c(1,1))
tores <- lm(wards$toprop04 ~ wards$govprop)$res;
kerryres <- lm(wards$kerryprop ~ wards$govprop)$res;
rngtores <- range(tores);
rngkerryres <- range(kerryres);
plot(rngtores, rngkerryres, type="n",
     ylab="residualized Kerry vote proportion", xlab="residualized turnout 2004")
points(tores, kerryres);
abline(lm(kerryres ~ tores))
dev.off()

postscript(file="wards2sD.ps", onefile=FALSE, horizontal=FALSE, width=6, height=6);
par(mfrow=c(2,2))
tores <- lm(wards$toprop04 ~ wards$govprop)$res;
kerryres <- lm(wards$kerryprop ~ wards$govprop)$res;
rngtores <- range(tores);
rngkerryres <- range(kerryres);
for (i in 1:4) {
  tdat <- wards[asc(wards$county)==ucounty[i],];
  tdat$tores <- tores[asc(wards$county)==ucounty[i]];
  tdat$kerryres <- kerryres[asc(wards$county)==ucounty[i]];
  print(uCounty[i]);

  plot(rngtores, rngkerryres, type="n", main=uCounty[i],
       ylab="residualized Kerry vote proportion", xlab="residualized turnout change 2004")
  points(tdat$tores, tdat$kerryres);
  abline(lm(tdat$kerryres ~ tdat$tores))
}
dev.off()

postscript(file="wards2sE.ps", onefile=FALSE, horizontal=FALSE, width=6, height=6);
par(mfrow=c(1,1))
tores <- lm(wards$toprop04 ~ wards$toprop02)$res;
I1res <- lm(wards$I1prop04 ~ wards$toprop02)$res;
rngtores <- range(tores);
rngI1res <- range(I1res);
plot(rngI1res, rngtores, type="n",
     xlab="residualized Issue 1 Yes vote", ylab="residualized turnout 2004")
points(I1res, tores);
abline(lm(tores ~ I1res))
dev.off()

postscript(file="wards2sF.ps", onefile=FALSE, horizontal=FALSE, width=6, height=6);
par(mfrow=c(2,2))
tores <- lm(wards$toprop04 ~ wards$toprop02)$res;
I1res <- lm(wards$I1prop04 ~ wards$toprop02)$res;
rngtores <- range(tores);
rngI1res <- range(I1res);
for (i in 1:4) {
  tdat <- wards[asc(wards$county)==ucounty[i],];
  tdat$tores <- tores[asc(wards$county)==ucounty[i]];
  tdat$I1res <- I1res[asc(wards$county)==ucounty[i]];
  print(uCounty[i]);

  plot(rngI1res, rngtores, type="n", main=uCounty[i],
       xlab="residualized Issue 1 Yes vote", ylab="residualized turnout 2004")
  points(tdat$I1res, tdat$tores);
  abline(lm(tdat$tores ~ tdat$I1res))
}
dev.off()

postscript(file="wards2sG.ps", onefile=FALSE, horizontal=FALSE, width=6, height=6);
par(mfrow=c(1,1))
plot(c(0,1),c(0,1), type="n",
     ylab="Kerry vote proportion", xlab="Hagan vote proportion 2002");
points(wards$govprop, wards$kerryprop);
abline(lm(wards$kerryprop ~ wards$govprop));
dev.off()

postscript(file="wards2sH.ps", onefile=FALSE, horizontal=FALSE, width=6, height=6);
par(mfrow=c(2,2))
for (i in 1:4) {
  tdat <- wards[asc(wards$county)==ucounty[i],];
  print(uCounty[i]);

  plot(c(0,1), c(0,1), type="n", main=uCounty[i],
       ylab="Kerry vote proportion", xlab="Hagan vote proportion 2002")
  points(tdat$govprop, tdat$kerryprop);
  abline(lm(tdat$kerryprop ~ tdat$govprop))
}
dev.off()

postscript(file="wards2sI.ps", onefile=FALSE, horizontal=FALSE, width=6, height=6);
par(mfrow=c(2,2))
for (i in 1:4) {
  tdat <- wards[asc(wards$county)==ucounty[i],];
  print(uCounty[i]);

  plot(tdat$regvoters02, tdat$regvoters04, main=uCounty[i],
       ylab="registered voters 2004", xlab="registered voters 2002");
#  abline(lm(tdat$regvoters04 ~ tdat$regvoters02))
  abline(0,1)
}
dev.off()

postscript(file="wards2sJ.ps", onefile=FALSE, horizontal=FALSE, width=6, height=6);
rngtochg <- range(wards$tochg);
rngrvchg <- range((wards$regvoters04 - wards$regvoters02)/wards$regvoters02);
par(mfrow=c(2,2))
for (i in 1:4) {
  tdat <- wards[asc(wards$county)==ucounty[i],];
  print(uCounty[i]);

  plot(rngrvchg, rngtochg, type="n", main=uCounty[i],
       ylab="turnout change 2002 to 2004", xlab="registration change 2002 to 2004");
  points((tdat$regvoters04 - tdat$regvoters02)/tdat$regvoters02, tdat$tochg);
  abline(lm(tdat$tochg ~ I((tdat$regvoters04 - tdat$regvoters02)/tdat$regvoters02)))
}
dev.off()

postscript(file="wards2sK.ps", onefile=FALSE, horizontal=FALSE, width=6, height=6);
rngrvchg <- range((wards$regvoters04 - wards$regvoters02)/wards$regvoters02);
par(mfrow=c(2,2))
for (i in 1:4) {
  tdat <- wards[asc(wards$county)==ucounty[i],];
  print(uCounty[i]);

  plot(rngrvchg, c(0,1), type="n", main=uCounty[i],
       ylab="Kerry vote proportion", xlab="registration change 2002 to 2004");
  points((tdat$regvoters04 - tdat$regvoters02)/tdat$regvoters02, tdat$kerryprop);
  abline(lm(tdat$kerryprop ~ I((tdat$regvoters04 - tdat$regvoters02)/tdat$regvoters02)))
}
dev.off()

