# production

load(".Rdata.wardturnout2mN");

set.seed(19342);
if (!exists("multinomRob"))
	library(multinomRob, lib.loc="/home/wrm1/lib/R/");

logit <- function(x) {
  z <- ifelse(x<=0, .0000001, ifelse(x>=1, 1-.0000001, x));
  return( log(z/(1-z)) );
}

asc <- function(x) { as.character(x) }

ucounty <- c("CUYAHOGA", "FRANKLIN", "HAMILTON", "LUCAS");
uCounty <- c("Cuyahoga", "Franklin", "Hamilton", "Lucas");

model1 <- list(votescast04 ~ vlogit02 + I1logit04,
              nonvote04 ~ -1
              );

simturnout <- function(x,m) {  # robust estimates
  bC  <- zall[[ucounty[1]]]$coefficients[,1]
  bF <- zall[[ucounty[2]]]$coefficients[,1]
  bH <- zall[[ucounty[3]]]$coefficients[,1]
  bL  <- zall[[ucounty[4]]]$coefficients[,1]

  l <- function(n) { 1/(1+exp(-n)) }

  tC <- l(bC[1] + bC[2] * m[1,1] + bC[3] * x[1,]);
  tF  <- l(bF[1] + bF[2] * m[2,1] + bF[3] * x[2,]);
  tH  <- l(bH[1] + bH[2] * m[3,1] + bH[3] * x[3,]);
  tL   <- l(bL[1] + bL[2] * m[4,1] + bL[3] * x[4,]);

  return(list(C=tC, F=tF, H=tH, L=tL));
}

mmat <- matrix(0, 4, 1);
dimnames(mmat) <- list(ucounty, NULL);
for (i in ucounty) {
  tdat <- wards[asc(wards$county) == i,];
  mmat[i,] <- median(tdat$vlogit02)
}
print(mmat);

qmat <- matrix(0, 4, 3);
dimnames(qmat) <- list(ucounty, NULL);
for (i in ucounty) {
  tdat <- wards[asc(wards$county) == i,];
  qmat[i,] <- quantile(tdat$I1logit04)[2:4]
}
print(qmat);

# robust
tsim <- simturnout(qmat,mmat);
print(tsim);
tfmt <- t(sapply(tsim,
          function(x){sapply(x,function(n){as.real(sprintf("%6.3f",n))})}));
print(tfmt);
